@@ -292,7 +292,7 @@ pub enum CliCommand {
         seed: Option<String>,
         identity_account: SignerIndex,
         authorized_voter: Option<Pubkey>,
-        authorized_withdrawer: Option<Pubkey>,
+        authorized_withdrawer: Pubkey,
         commission: u8,
         memo: Option<String>,
     },
@@ -1379,7 +1379,7 @@ pub fn process_command(config: &CliConfig) -> ProcessResult {
             seed,
             *identity_account,
             authorized_voter,
-            authorized_withdrawer,
+            *authorized_withdrawer,
             *commission,
             memo.as_ref(),
         ),
@@ -1943,7 +1943,7 @@ mod tests {
             seed: None,
             identity_account: 2,
             authorized_voter: Some(bob_pubkey),
-            authorized_withdrawer: Some(bob_pubkey),
+            authorized_withdrawer: bob_pubkey,
             commission: 0,
             memo: None,
         };
@@ -1951,17 +1951,36 @@ mod tests {
         let result = process_command(&config);
         assert!(result.is_ok());
 
+        let vote_account_info_response = json!(Response {
+            context: RpcResponseContext { slot: 1 },
+            value: json!({
+                "data": ["KLUv/QBYNQIAtAIBAAAAbnoc3Smwt4/ROvTFWY/v9O8qlxZuPKby5Pv8zYBQW/EFAAEAAB8ACQD6gx92zAiAAecDP4B2XeEBSIx7MQeung==", "base64+zstd"],
+                "lamports": 42,
+                "owner": "Vote111111111111111111111111111111111111111",
+                "executable": false,
+                "rentEpoch": 1,
+            }),
+        });
+        let mut mocks = HashMap::new();
+        mocks.insert(RpcRequest::GetAccountInfo, vote_account_info_response);
+        let rpc_client = RpcClient::new_mock_with_mocks("".to_string(), mocks);
+        let mut vote_config = CliConfig {
+            rpc_client: Some(Arc::new(rpc_client)),
+            json_rpc_url: "http://127.0.0.1:8899".to_string(),
+            ..CliConfig::default()
+        };
+        let current_authority = keypair_from_seed(&[5; 32]).unwrap();
         let new_authorized_pubkey = solana_sdk::pubkey::new_rand();
-        config.signers = vec![&bob_keypair];
-        config.command = CliCommand::VoteAuthorize {
+        vote_config.signers = vec![&current_authority];
+        vote_config.command = CliCommand::VoteAuthorize {
             vote_account_pubkey: bob_pubkey,
             new_authorized_pubkey,
-            vote_authorize: VoteAuthorize::Voter,
+            vote_authorize: VoteAuthorize::Withdrawer,
             memo: None,
             authorized: 0,
             new_authorized: None,
         };
-        let result = process_command(&config);
+        let result = process_command(&vote_config);
         assert!(result.is_ok());
 
         let new_identity_keypair = Keypair::new();
@@ -2144,7 +2163,7 @@ mod tests {
             seed: None,
             identity_account: 2,
             authorized_voter: Some(bob_pubkey),
-            authorized_withdrawer: Some(bob_pubkey),
+            authorized_withdrawer: bob_pubkey,
             commission: 0,
             memo: None,
         };
